# -*-makefile-*-
#
# Copyright (C) 2013 by Trilokesh Rangam <lokesh.r@phytec.in>
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_GRAPHICS_SDK) += graphics_sdk

#
# Paths and names
#
GRAPHICS_SDK_VERSION	:= 4_10_00_01
GRAPHICS_SDK_MD5	:= 15a3ccb66e98580e474fc112565f66b6
GRAPHICS_SDK		:= Graphics_SDK_setuplinux_$(GRAPHICS_SDK_VERSION)
GRAPHICS_SDK_SUFFIX	:= bin
GRAPHICS_SDK_URL	:= http://downloads.ti.com/dsps/dsps_public_sw/sdo_sb/targetcontent/gfxsdk/$(GRAPHICS_SDK_VERSION)/exports/$(GRAPHICS_SDK)_hardfp_minimal_demos.$(GRAPHICS_SDK_SUFFIX)
GRAPHICS_SDK_SOURCE	:= $(SRCDIR)/$(GRAPHICS_SDK)_hardfp_minimal_demos.$(GRAPHICS_SDK_SUFFIX)
GRAPHICS_SDK_DIR	:= $(BUILDDIR)/$(GRAPHICS_SDK)
GRAPHICS_SDK_LICENSE	:= TSPA
GRAPHICS_SDK_INS_PATH	:= $(GRAPHICS_SDK_DIR)/gfx_rel_es8.x

ifdef PTXCONF_GRAPHICS_SDK
$(STATEDIR)/kernel.targetinstall.post: $(STATEDIR)/graphics_sdk.targetinstall
endif

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

$(STATEDIR)/graphics_sdk.extract:
	@$(call targetinfo)
	@$(call clean, $(GRAPHICS_SDK_DIR))
	@rm -rf $(GRAPHICS_SDK_DIR)
	@[ -x $(GRAPHICS_SDK_SOURCE) ] || chmod +x $(GRAPHICS_SDK_SOURCE)
	@$(GRAPHICS_SDK_SOURCE) --prefix $(GRAPHICS_SDK_DIR) --mode console
	@$(call patchin, GRAPHICS_SDK, $(GRAPHICS_SDK_DIR))
	@$(call touch)

GRAPHICS_SDK_ENV := \
	BUILD=release \
	TI_PLATFORM=ti335x \
	OMAPES=8.x \
	SDK_HOME=$(GRAPHICS_SDK_DIR) \
	SDK_KERNEL_INSTALL_DIR=$(KERNEL_DIR) \
	SDK_TARGETFS_INSTALL_DIR=$(GRAPHICS_SDK_DIR)/targetfs \
	SDK_GRAPHICS_INSTALL_DIR=$(GRAPHICS_SDK_DIR) \
	SDK_TOOLCHAIN=$(PTXCONF_GNU_TARGET)- \
	SDK_TOOLPATH=$(shell readlink -f selected_toolchain) \

# ----------------------------------------------------------------------------
#  Compile:
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_sdk.compile:
	@$(call targetinfo)
	@$(MAKE) $(GRAPHICS_SDK_ENV) -C $(GRAPHICS_SDK_DIR) all
	@$(call touch)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

$(STATEDIR)/graphics_sdk.install:
	@$(call targetinfo)
	@cp $(GRAPHICS_SDK_INS_PATH)/*.so $(SYSROOT)/usr/lib/
	@cp $(GRAPHICS_SDK_INS_PATH)/*.a $(SYSROOT)/usr/lib/

	@cp -r $(GRAPHICS_SDK_DIR)/include/OGLES/GLES $(SYSROOT)/usr/include

	@cp -r $(GRAPHICS_SDK_DIR)/include/OGLES2/GLES2 $(SYSROOT)/usr/include

	# common for both, OGLES2 and OGLES
	@cp -r $(GRAPHICS_SDK_DIR)/include/OGLES2/EGL $(SYSROOT)/usr/include
	@cp -r $(GRAPHICS_SDK_DIR)/include/OGLES2/EWS $(SYSROOT)/usr/include
	@cp -r $(GRAPHICS_SDK_DIR)/include/OGLES2/KHR $(SYSROOT)/usr/include

	@cp -r $(GRAPHICS_SDK_DIR)/include/pvr2d $(SYSROOT)/usr/include
	@cp -r $(GRAPHICS_SDK_DIR)/include/wsegl $(SYSROOT)/usr/include
	@cp -r $(GRAPHICS_SDK_DIR)/include/bufferclass_ti $(SYSROOT)/usr/include

	@cp -r $(GRAPHICS_SDK_DIR)/GFX_Linux_SDK $(SYSROOT)/usr/local

	@$(call touch)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/graphics_sdk.targetinstall:
	@$(call targetinfo)
	$(KERNEL_PATH) $(KERNEL_ENV) $(MAKE) $(KERNEL_MAKEVARS) \
		-C $(KERNEL_DIR) \
		M=$(GRAPHICS_SDK_DIR)/GFX_Linux_KM \
		modules_install

	@$(call install_init, graphics_sdk)
	@$(call install_fixup, graphics_sdk,PRIORITY,optional)
	@$(call install_fixup, graphics_sdk,SECTION,base)
	@$(call install_fixup, graphics_sdk,AUTHOR,"Trilokesh Rangam <lokesh.r@phytec.in>")
	@$(call install_fixup, graphics_sdk,DESCRIPTION,missing)

	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libGLES_CM.so, /usr/lib/libGLES_CM.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libusc.so, /usr/lib/libusc.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libGLESv2.so, /usr/lib/libGLESv2.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libglslcompiler.so, /usr/lib/libglslcompiler.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libIMGegl.so, /usr/lib/libIMGegl.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libEGL.so, /usr/lib/libEGL.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libpvr2d.so, /usr/lib/libpvr2d.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libpvrPVR2D_BLITWSEGL.so, /usr/lib/libpvrPVR2D_BLITWSEGL.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libpvrPVR2D_FLIPWSEGL.so, /usr/lib/libpvrPVR2D_FLIPWSEGL.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libpvrPVR2D_FRONTWSEGL.so, /usr/lib/libpvrPVR2D_FRONTWSEGL.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libpvrPVR2D_LINUXFBWSEGL.so, /usr/lib/libpvrPVR2D_LINUXFBWSEGL.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libsrv_um.so, /usr/lib/libsrv_um.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libsrv_init.so, /usr/lib/libsrv_init.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/libPVRScopeServices.so, /usr/lib/libPVRScopeServices.so)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/sgx_clipblit_test, /usr/local/bin/sgx_clipblit_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/sgx_blit_test, /usr/local/bin/sgx_blit_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/services_test, /usr/local/bin/services_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/sgx_init_test, /usr/local/bin/sgx_init_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/pvrsrvctl, /usr/local/bin/pvrsrvctl)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/sgx_flip_test, /usr/local/bin/sgx_flip_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/sgx_render_flip_test, /usr/local/bin/sgx_render_flip_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, $(GRAPHICS_SDK_INS_PATH)/pvr2d_test, /usr/local/bin/pvr2d_test)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/glsltest1_vertshader.txt, /usr/local/bin/glsltest1_vertshader.txt)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/glsltest1_fragshaderA.txt, /usr/local/bin/glsltest1_fragshaderA.txt)
	@$(call install_copy, graphics_sdk, 0, 0, 0644, $(GRAPHICS_SDK_INS_PATH)/glsltest1_fragshaderB.txt, /usr/local/bin/glsltest1_fragshaderB.txt)

	@$(call install_copy, graphics_sdk, 0, 0, 0775, $(GRAPHICS_SDK_INS_PATH)/rc.pvr, /etc/init.d/rc.pvr)

	@$(call install_alternative, graphics_sdk, 0, 0, 775, /etc/init.d/sgx_setup)

ifneq ($(call remove_quotes,$(PTXCONF_GRAPHICS_SDK_BBINIT_LINK)),)
	@$(call install_link, graphics_sdk, \
	../init.d/sgx_setup, \
	/etc/rc.d/$(PTXCONF_GRAPHICS_SDK_BBINIT_LINK))
endif

ifdef PTXCONF_GRAPHICS_SDK_DEMOS
	@$(call install_copy, graphics_sdk, 0, 0, 0755, \
		$(GRAPHICS_SDK_DIR)/gfxsdkdemos/ogles2/OGLES2MagicLantern, \
		/usr/local/bin/OGLES2MagicLantern)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, \
		$(GRAPHICS_SDK_DIR)/gfxsdkdemos/ogles2/OGLES2ChameleonMan, \
		/usr/local/bin/OGLES2ChameleonMan)

	@$(call install_copy, graphics_sdk, 0, 0, 0755, \
		$(GRAPHICS_SDK_DIR)/gfxsdkdemos/ogles/OGLESEvilSkull, \
		/usr/local/bin/OGLESEvilSkull)
	@$(call install_copy, graphics_sdk, 0, 0, 0755, \
		$(GRAPHICS_SDK_DIR)/gfxsdkdemos/ogles/OGLESFilmTV, \
		/usr/local/bin/OGLESFilmTV)
endif
	@$(call install_finish, graphics_sdk)

	@$(call touch)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

$(STATEDIR)/graphics_sdk.clean:
	@$(call targetinfo)
	@$(call clean_pkg, GRAPHICS_SDK)

# vim: syntax=make
